/***************************************************************************
                          ProgressDialog.h  -  description
                             -------------------
    begin                : Die Mai 15 15:34:19 CEST 2001
    copyright            : (C) 2001 by Dominik Seichter
    email                : domseichter@web.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful, but   *
 *   WITHOUT ANY WARRANTY; without even the implied warranty of            *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      *
 *   General Public License for more details.                              *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the Free Software           *
 *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307   *
 *   USA.                                                                  *
 *                                                                         *
 *   For license exceptions see LICENSE.EXC file, attached with the source *
 *   code.                                                                 *
 *                                                                         *
 ***************************************************************************/

#ifndef __PROGRESSDIALOG_H__
#define __PROGRESSDIALOG_H__

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

// QT Includes
#include <qprogressdialog.h>
#include <qlayout.h>
#include <qmultilineedit.h>
#include <qpushbutton.h>
#include <qprogressbar.h>

class ProgressDialog : public QProgressDialog
{ 
    Q_OBJECT

    public:
        ProgressDialog( QWidget* parent = 0, bool p = false, const char* name = 0, bool modal = FALSE, WFlags fl = 0 );
        ~ProgressDialog();
	
	void print(const QString& in, const QString& out="") ;
	void inc();
	void init( int numOfFiles );
	
    private slots:
        void quitAll();
	
    protected:
        bool preview;
	int done;
};

#endif // __PROGRESSDIALOG_H__
